@@ -9,11 +9,14 @@
 # @Description  :
 import os
 import numpy as np
+import pretty_errors
 
-from .cprint import cprint
-from .timer import timer
-from .logger import *
 from .pipe import *
+from .logger import *
+from .timer import timer
+from .cprint import cprint
+from .hashtrick import murmurhash
+from .NT import NT
 
 get_module_path = lambda path, file=__file__: \
     os.path.normpath(os.path.join(os.getcwd(), os.path.dirname(file), path))
